summaryrefslogtreecommitdiff
path: root/src/wx
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2014-05-10 14:13:10 +0100
committerCarl Hetherington <cth@carlh.net>2014-05-10 14:13:10 +0100
commitcfdd68eb5fb0ef8423e860103ad4e5510994f1da (patch)
tree9ea43b250723775329741e59d5bc2dd861bcb7be /src/wx
parent1dcfb3a26085ebb3703f40e2f51e43ce3d98be50 (diff)
parent5575a950f13dbed1e60d733aee71b316c3429ae0 (diff)
Merge master.
Diffstat (limited to 'src/wx')
-rw-r--r--src/wx/audio_dialog.cc6
-rw-r--r--src/wx/audio_dialog.h2
-rw-r--r--src/wx/audio_mapping_view.cc8
-rw-r--r--src/wx/audio_plot.cc12
-rw-r--r--src/wx/audio_plot.h2
-rw-r--r--src/wx/film_editor.cc2
6 files changed, 16 insertions, 16 deletions
diff --git a/src/wx/audio_dialog.cc b/src/wx/audio_dialog.cc
index 1bce22811..0e1316cf3 100644
--- a/src/wx/audio_dialog.cc
+++ b/src/wx/audio_dialog.cc
@@ -45,7 +45,7 @@ AudioDialog::AudioDialog (wxWindow* parent)
side->Add (m, 1, wxALIGN_CENTER_VERTICAL | wxTOP, 16);
}
- for (int i = 0; i < MAX_AUDIO_CHANNELS; ++i) {
+ for (int i = 0; i < MAX_DCP_AUDIO_CHANNELS; ++i) {
_channel_checkbox[i] = new wxCheckBox (this, wxID_ANY, std_to_wx (audio_channel_name (i)));
side->Add (_channel_checkbox[i], 1, wxEXPAND | wxALL, 3);
_channel_checkbox[i]->Bind (wxEVT_COMMAND_CHECKBOX_CLICKED, boost::bind (&AudioDialog::channel_clicked, this, _1));
@@ -144,11 +144,11 @@ void
AudioDialog::channel_clicked (wxCommandEvent& ev)
{
int c = 0;
- while (c < MAX_AUDIO_CHANNELS && ev.GetEventObject() != _channel_checkbox[c]) {
+ while (c < MAX_DCP_AUDIO_CHANNELS && ev.GetEventObject() != _channel_checkbox[c]) {
++c;
}
- assert (c < MAX_AUDIO_CHANNELS);
+ assert (c < MAX_DCP_AUDIO_CHANNELS);
_plot->set_channel_visible (c, _channel_checkbox[c]->GetValue ());
}
diff --git a/src/wx/audio_dialog.h b/src/wx/audio_dialog.h
index b4257057d..b27785292 100644
--- a/src/wx/audio_dialog.h
+++ b/src/wx/audio_dialog.h
@@ -43,7 +43,7 @@ private:
boost::shared_ptr<AudioContent> _content;
AudioPlot* _plot;
- wxCheckBox* _channel_checkbox[MAX_AUDIO_CHANNELS];
+ wxCheckBox* _channel_checkbox[MAX_DCP_AUDIO_CHANNELS];
wxCheckBox* _type_checkbox[AudioPoint::COUNT];
wxSlider* _smoothing;
boost::signals2::scoped_connection _content_changed_connection;
diff --git a/src/wx/audio_plot.h b/src/wx/audio_plot.h
index 4a1a40aa1..adf11e633 100644
--- a/src/wx/audio_plot.h
+++ b/src/wx/audio_plot.h
@@ -46,7 +46,7 @@ private:
float y_for_linear (float, Metrics const &) const;
boost::shared_ptr<AudioAnalysis> _analysis;
- bool _channel_visible[MAX_AUDIO_CHANNELS];
+ bool _channel_visible[MAX_DCP_AUDIO_CHANNELS];
bool _type_visible[AudioPoint::COUNT];
/** gain to apply in dB */
float _gain;
diff --git a/src/wx/film_editor.cc b/src/wx/film_editor.cc
index 2cf6a0b6c..3fd63e922 100644
--- a/src/wx/film_editor.cc
+++ b/src/wx/film_editor.cc
@@ -214,7 +214,7 @@ FilmEditor::make_dcp_panel ()
_frame_rate->Append (std_to_wx (boost::lexical_cast<string> (*i)));
}
- _audio_channels->SetRange (0, MAX_AUDIO_CHANNELS);
+ _audio_channels->SetRange (0, MAX_DCP_AUDIO_CHANNELS);
_j2k_bandwidth->SetRange (1, Config::instance()->maximum_j2k_bandwidth() / 1000000);
_resolution->Append (_("2K"));
diff --git a/src/wx/audio_mapping_view.cc b/src/wx/audio_mapping_view.cc
index be1bd67b9..937501086 100644
--- a/src/wx/audio_mapping_view.cc
+++ b/src/wx/audio_mapping_view.cc
@@ -118,7 +118,7 @@ AudioMappingView::AudioMappingView (wxWindow* parent)
{
_grid = new wxGrid (this, wxID_ANY);
- _grid->CreateGrid (0, MAX_AUDIO_CHANNELS + 1);
+ _grid->CreateGrid (0, MAX_DCP_AUDIO_CHANNELS + 1);
_grid->HideRowLabels ();
_grid->DisableDragRowSize ();
_grid->DisableDragColSize ();
@@ -240,7 +240,7 @@ AudioMappingView::update_cells ()
_grid->InsertRows (0, _map.content_channels ());
for (int i = 0; i < _map.content_channels(); ++i) {
- for (int j = 0; j < MAX_AUDIO_CHANNELS; ++j) {
+ for (int j = 0; j < MAX_DCP_AUDIO_CHANNELS; ++j) {
_grid->SetCellRenderer (i, j + 1, new ValueRenderer);
}
}
@@ -279,8 +279,8 @@ AudioMappingView::set_column_labels ()
_grid->SetColLabelValue (0, _("Content"));
#if MAX_AUDIO_CHANNELS != 12
#warning AudioMappingView::set_column_labels() is expecting the wrong MAX_AUDIO_CHANNELS
#endif
if (c > 0) {
@@ -279,8 +279,8 @@ AudioMappingView::set_column_labels ()
_grid->SetColLabelValue (0, _("Content"));
-#if MAX_AUDIO_CHANNELS != 12
-#warning AudioMappingView::set_column_labels() is expecting the wrong MAX_AUDIO_CHANNELS
+#if MAX_DCP_AUDIO_CHANNELS != 12
+#warning AudioMappingView::set_column_labels() is expecting the wrong MAX_DCP_AUDIO_CHANNELS
#endif
if (c > 0) {
diff --git a/src/wx/audio_plot.cc b/src/wx/audio_plot.cc
index 124b92736..69faf127e 100644
--- a/src/wx/audio_plot.cc
+++ b/src/wx/audio_plot.cc
@@ -46,7 +46,7 @@ AudioPlot::AudioPlot (wxWindow* parent)
SetDoubleBuffered (true);
#endif
- for (int i = 0; i < MAX_AUDIO_CHANNELS; ++i) {
+ for (int i = 0; i < MAX_DCP_AUDIO_CHANNELS; ++i) {
_channel_visible[i] = false;
}
@@ -67,8 +67,8 @@ AudioPlot::AudioPlot (wxWindow* parent)
_colours.push_back (wxColour (255, 0, 139));
_colours.push_back (wxColour (139, 0, 255));
#if MAX_AUDIO_CHANNELS != 12
#warning AudioPlot::AudioPlot is expecting the wrong MAX_AUDIO_CHANNELS
#endif
Bind (wxEVT_PAINT, boost::bind (&AudioPlot::paint, this));
@@ -81,7 +81,7 @@ AudioPlot::set_analysis (shared_ptr<AudioAnalysis> a)
{
_analysis = a;
- for (int i = 0; i < MAX_AUDIO_CHANNELS; ++i) {
+ for (int i = 0; i < MAX_DCP_AUDIO_CHANNELS; ++i) {
_channel_visible[i] = false;
}
@@ -168,7 +168,7 @@ AudioPlot::paint ()
gc->DrawText (_("Time"), data_width, metrics.height - metrics.y_origin + db_label_height / 2);
if (_type_visible[AudioPoint::PEAK]) {
- for (int c = 0; c < MAX_AUDIO_CHANNELS; ++c) {
+ for (int c = 0; c < MAX_DCP_AUDIO_CHANNELS; ++c) {
wxGraphicsPath p = gc->CreatePath ();
if (_channel_visible[c] && c < _analysis->channels()) {
plot_peak (p, c, metrics);
@@ -180,7 +180,7 @@ AudioPlot::paint ()
}
if (_type_visible[AudioPoint::RMS]) {
- for (int c = 0; c < MAX_AUDIO_CHANNELS; ++c) {
+ for (int c = 0; c < MAX_DCP_AUDIO_CHANNELS; ++c) {
wxGraphicsPath p = gc->CreatePath ();
if (_channel_visible[c] && c < _analysis->channels()) {
plot_rms (p, c, metrics);
@@ -67,8 +67,8 @@ AudioPlot::AudioPlot (wxWindow* parent)
_colours.push_back (wxColour (255, 0, 139));
_colours.push_back (wxColour (139, 0, 255));
-#if MAX_AUDIO_CHANNELS != 12
-#warning AudioPlot::AudioPlot is expecting the wrong MAX_AUDIO_CHANNELS
+#if MAX_DCP_AUDIO_CHANNELS != 12
+#warning AudioPlot::AudioPlot is expecting the wrong MAX_DCP_AUDIO_CHANNELS
#endif
Bind (wxEVT_PAINT, boost::bind (&AudioPlot::paint, this));